import { Callback, CallbackOptions, Data } from './models';
/**
 * Describes a SpriteSpin plugin
 *
 * @public
 */
export interface SpriteSpinPlugin extends CallbackOptions {
    [key: string]: Callback | string;
    name?: string;
}
/**
 * Registers a plugin.
 *
 * @remarks
 * Use this to add custom Rendering or Updating modules that can be addressed with the 'module' option.
 *
 * @public
 * @param name - The name of the plugin
 * @param plugin - The plugin implementation
 */
export declare function registerPlugin(name: string, plugin: SpriteSpinPlugin): SpriteSpinPlugin;
/**
 * Registers a plugin.
 *
 * @public
 * @deprecated Use {@link registerPlugin} instead
 * @param name - The name of the plugin
 * @param plugin - The plugin implementation
 */
export declare function registerModule(name: string, plugin: SpriteSpinPlugin): void;
/**
 * Gets an active plugin by name
 *
 * @internal
 * @param name - The name of the plugin
 */
export declare function getPlugin(name: any): SpriteSpinPlugin;
/**
 * Replaces module names on given SpriteSpin data and replaces them with actual implementations.
 * @internal
 */
export declare function applyPlugins(data: Data): void;
